summaryrefslogtreecommitdiff
path: root/src/gui/serverdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/serverdialog.cpp')
-rw-r--r--src/gui/serverdialog.cpp14
1 files changed, 5 insertions, 9 deletions
diff --git a/src/gui/serverdialog.cpp b/src/gui/serverdialog.cpp
index 9051a5f2..16de45a8 100644
--- a/src/gui/serverdialog.cpp
+++ b/src/gui/serverdialog.cpp
@@ -350,16 +350,12 @@ void ServerDialog::loadServers()
{
if (xmlStrEqual(server->name, BAD_CAST "server"))
{
- //check wether the version matches
- #ifdef MANASERV_SUPPORT
- if (XML::getProperty(server, "type", "unknown") != "MANASERV")
- continue;
- #endif
-
- #ifdef EATHENA_SUPPORT
- if (XML::getProperty(server, "type", "unknown") != "EATHENA")
+ //check wether the build matches
+ if (compareStrI(XML::getProperty(server, "type", "unknown"),
+ SERVER_BUILD))
+ {
continue;
- #endif
+ }
currentServer.clear();
currentServer.name = XML::getProperty(server, "name", std::string());